Coverage report

# Coverage report: 92%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 1011 | 81 | 5 | 92%
configman | 6 | 0 | 0 | 100%
configman.config_exceptions | 12 | 0 | 0 | 100%
configman.config_file_future_proxy | 2 | 0 | 0 | 100%
configman.config_manager | 332 | 10 | 0 | 97%
configman.converters | 85 | 4 | 0 | 95%
configman.datetime_util | 38 | 0 | 0 | 100%
configman.def_sources | 19 | 1 | 0 | 95%
configman.def_sources.for_json | 9 | 3 | 0 | 67%
configman.def_sources.for_mappings | 30 | 3 | 0 | 90%
configman.def_sources.for_modules | 5 | 3 | 0 | 40%
configman.dotdict | 4 | 0 | 0 | 100%
configman.namespace | 32 | 0 | 0 | 100%
configman.option | 48 | 0 | 5 | 100%
configman.value_sources | 69 | 5 | 0 | 93%
configman.value_sources.for_conf | 55 | 11 | 0 | 80%
configman.value_sources.for_configparse | 69 | 19 | 0 | 72%
configman.value_sources.for_getopt | 107 | 9 | 0 | 92%
configman.value_sources.for_json | 56 | 12 | 0 | 79%
configman.value_sources.for_mapping | 14 | 1 | 0 | 93%
configman.value_sources.source_exceptions | 19 | 0 | 0 | 100%